summaryrefslogtreecommitdiffstats
path: root/src/usr/fapi2/plat_attr_override_sync.C
diff options
context:
space:
mode:
authorDean Sanner <dsanner@us.ibm.com>2016-08-16 15:57:35 -0500
committerDaniel M. Crowell <dcrowell@us.ibm.com>2016-09-21 23:12:46 -0400
commit35947c5fc61541987c6acae263752a8593615ff1 (patch)
treea14fa2208666cc72169dafe51816b52129deebfb /src/usr/fapi2/plat_attr_override_sync.C
parentfe3a5bea6fcadd8ef33dbd155ffc90add0c71aba (diff)
downloadtalos-hostboot-35947c5fc61541987c6acae263752a8593615ff1.tar.gz
talos-hostboot-35947c5fc61541987c6acae263752a8593615ff1.zip
Update getAttrTankTargetPosData to handle MCS, MCA correctly
Change-Id: I7e1d2b942d4fe4d915f50e9626e7c4cbf20432e4 Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/28361 Tested-by: Jenkins Server <pfd-jenkins+hostboot@us.ibm.com> Reviewed-by: Martin Gloff <mgloff@us.ibm.com> Tested-by: FSP CI Jenkins <fsp-CI-jenkins+hostboot@us.ibm.com> Reviewed-by: Daniel M. Crowell <dcrowell@us.ibm.com>
Diffstat (limited to 'src/usr/fapi2/plat_attr_override_sync.C')
-rw-r--r--src/usr/fapi2/plat_attr_override_sync.C10
1 files changed, 8 insertions, 2 deletions
diff --git a/src/usr/fapi2/plat_attr_override_sync.C b/src/usr/fapi2/plat_attr_override_sync.C
index 765e758b9..b3be61dbc 100644
--- a/src/usr/fapi2/plat_attr_override_sync.C
+++ b/src/usr/fapi2/plat_attr_override_sync.C
@@ -690,10 +690,16 @@ void AttrOverrideSync::triggerAttrSync()
if(l_fType == fapi2::TARGET_TYPE_NONE)
{
- //Didn't allocate fapi2 target, don't need to free
continue; //not a FAPI2 target -- skip to next target
}
+ //skip if not functional
+ if(l_pTarget->getAttr<TARGETING::ATTR_HWAS_STATE>().functional
+ != true)
+ {
+ continue;
+ }
+
TARGETING::EntityPath phys_path_ptr =
l_pTarget->getAttr<TARGETING::ATTR_PHYS_PATH>();
FAPI_INF("triggerAttrSync: HUID 0x%X, fapi type[%x] [%s]",
@@ -709,7 +715,7 @@ void AttrOverrideSync::triggerAttrSync()
uint8_t l_node = 0;
l_pTarget->getAttrTankTargetPosData(l_pos, l_unitPos, l_node);
//Loop on all fapi targets under this target type
size_t l_elems = 0;
const AttributeSyncInfo * l_attrs =
get_fapi_target_attr_array(l_fType, l_elems);
@@ -709,7 +715,7 @@ void AttrOverrideSync::triggerAttrSync()
uint8_t l_node = 0;
l_pTarget->getAttrTankTargetPosData(l_pos, l_unitPos, l_node);
- //Loop on all fapi targets under this target type
+ //Loop on all fapi ATTR under this target type
size_t l_elems = 0;
const AttributeSyncInfo * l_attrs =
OpenPOWER on IntegriCloud